@@ -1,22 +1,14 @@
 /*
-** Copyright (C) 2002-2011 Erik de Castro Lopo <erikd@mega-nerd.com>
+** Copyright (c) 2002-2016, Erik de Castro Lopo <erikd@mega-nerd.com>
+** All rights reserved.
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
-**
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-** GNU General Public License for more details.
-**
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+** This code is released under 2-clause BSD license. Please see the
+** file at : https://github.com/libsndfile/libsamplerate/blob/master/COPYING
 */
 
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -24,6 +16,15 @@
 #include <math.h>
 #include <assert.h>
 
+#if (HAVE_FFTW3)
+#include <fftw3.h>
+#else
+static inline void
+fftw_cleanup (void)
+{	return ;
+}
+#endif
+
 #include <samplerate.h>
 
 #include "util.h"
@@ -57,6 +58,7 @@ main (void)
 		callback_test	(SRC_LINEAR, k, target) ;
 		} ;
 
+#ifdef ENABLE_SINC_FAST_CONVERTER
 	puts ("\n    Sinc interpolator :") ;
 	target = 100.0 ;
 	for (k = 1 ; k <= MAX_CHANNELS ; k++)
@@ -64,7 +66,9 @@ main (void)
 		process_test	(SRC_SINC_FASTEST, k, target) ;
 		callback_test	(SRC_SINC_FASTEST, k, target) ;
 		} ;
+#endif
 
+	fftw_cleanup () ;
 	puts ("") ;
 
 	return 0 ;
