@@ -1,22 +1,14 @@
 /*
-** Copyright (C) 2002-2011 Erik de Castro Lopo <erikd@mega-nerd.com>
+** Copyright (c) 2002-2016, Erik de Castro Lopo <erikd@mega-nerd.com>
+** All rights reserved.
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
-**
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-** GNU General Public License for more details.
-**
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+** This code is released under 2-clause BSD license. Please see the
+** file at : https://github.com/libsndfile/libsamplerate/blob/master/COPYING
 */
 
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -26,6 +18,8 @@
 
 #if (HAVE_FFTW3)
 
+#include <fftw3.h>
+
 #include <samplerate.h>
 
 #include "util.h"
@@ -92,12 +86,13 @@ main (int argc, char *argv [])
 				{	1,	{ 0.01111111111 },		0.3,		1,	 73.0,	1.0 },
 				{	1,	{ 0.01111111111 },		1.0,		1,	150.0,	1.0 },
 				{	1,	{ 0.01111111111 },		1.001,		1,	 77.0,	1.0 },
-				{	2,	{ 0.011111, 0.324 },	1.9999,		2,	 16.0,	0.94 },
-				{	2,	{ 0.012345, 0.457 },	0.456789,	1,	 26.0,	0.96 },
+				{	2,	{ 0.011111, 0.324 },	1.9999,		2,	 15.0,	0.94 },
+				{	2,	{ 0.012345, 0.457 },	0.456789,	1,	 25.0,	0.96 },
 				{	1,	{ 0.3511111111 },		1.33,		1,	 22.0,	0.99 }
 				}
 			},
 
+#ifdef ENABLE_SINC_FAST_CONVERTER
 		{	SRC_SINC_FASTEST,
 			9,
 			BOOLEAN_TRUE,
@@ -112,7 +107,9 @@ main (int argc, char *argv [])
 				{	1,	{ 0.3511111111 },		1.33,		1,	 97.0,	1.0 }
 				}
 			},
+#endif
 
+#ifdef ENABLE_SINC_MEDIUM_CONVERTER
 		{	SRC_SINC_MEDIUM_QUALITY,
 			9,
 			BOOLEAN_TRUE,
@@ -122,26 +119,30 @@ main (int argc, char *argv [])
 				{	1,	{ 0.01111111111 },		1.0,		1,	157.0,	1.0 },
 				{	1,	{ 0.01111111111 },		1.001,		1,	148.0,	1.0 },
 				{	2,	{ 0.011111, 0.324 },	1.9999,		2,	127.0,	1.0 },
-				{	2,	{ 0.012345, 0.457 },	0.456789,	1,	124.0,	0.5 },
+				{	2,	{ 0.012345, 0.457 },	0.456789,	1,	123.0,	0.5 },
 				{	2,	{ 0.011111, 0.45 },		0.6,		1,	126.0,	0.5 },
 				{	1,	{ 0.43111111111 },		1.33,		1,	121.0,	1.0 }
 				}
 			},
+#endif
 
+#ifdef ENABLE_SINC_BEST_CONVERTER
 		{	SRC_SINC_BEST_QUALITY,
 			9,
 			BOOLEAN_TRUE,
-			{	{	1,	{ 0.01111111111 },		3.0,		1,	149.0,	1.0 },
+			{	{	1,	{ 0.01111111111 },		3.0,		1,	147.0,	1.0 },
 				{	1,	{ 0.01111111111 },		0.6,		1,	147.0,	1.0 },
 				{	1,	{ 0.01111111111 },		0.3,		1,	148.0,	1.0 },
 				{	1,	{ 0.01111111111 },		1.0,		1,	155.0,	1.0 },
 				{	1,	{ 0.01111111111 },		1.001,		1,	148.0,	1.0 },
-				{	2,	{ 0.011111, 0.324 },	1.9999,		2,	147.0,	1.0 },
-				{	2,	{ 0.012345, 0.457 },	0.456789,	1,	148.0,	0.5 },
-				{	2,	{ 0.011111, 0.45 },		0.6,		1,	149.0,	0.5 },
+				{	2,	{ 0.011111, 0.324 },	1.9999,		2,	146.0,	1.0 },
+				{	2,	{ 0.012345, 0.457 },	0.456789,	1,	147.0,	0.5 },
+				{	2,	{ 0.011111, 0.45 },		0.6,		1,	144.0,	0.5 },
 				{	1,	{ 0.43111111111 },		1.33,		1,	145.0,	1.0 }
 				}
 			},
+#endif
+
 		} ; /* snr_test_data */
 
 	double	best_snr, snr, freq3dB ;
@@ -178,6 +179,8 @@ main (int argc, char *argv [])
 		printf ("    Measured -3dB rolloff point      : %5.2f %%.\n\n", freq3dB) ;
 		} ;
 
+	fftw_cleanup () ;
+
 	return 0 ;
 } /* main */
 
@@ -219,7 +222,7 @@ snr_test (SINGLE_TEST *test_data, int number, int converter, int verbose)
 	else
 	{	input_len = BUFFER_LEN ;
 		output_len = (int) ceil (BUFFER_LEN * test_data->src_ratio) ;
-		output_len &= ((-1) << 4) ;
+		output_len &= ((~0u) << 4) ;
 		if (output_len > MAX_SPEC_LEN)
 			output_len = MAX_SPEC_LEN ;
 		input_len = (int) ceil (output_len / test_data->src_ratio) ;
@@ -256,7 +259,7 @@ snr_test (SINGLE_TEST *test_data, int number, int converter, int verbose)
 	if (verbose != 0)
 		printf ("\tOutput Len  :   %ld\n", src_data.output_frames_gen) ;
 
-	if (abs (src_data.output_frames_gen - output_len) > 4)
+	if (abs ((int) (src_data.output_frames_gen - output_len)) > 4)
 	{	printf ("\n\nLine %d : output data length should be %d.\n\n", __LINE__, output_len) ;
 		exit (1) ;
 		} ;
